# purpleml

Collection of tools for everyday machine learning and data science tasks ... probaby hopelessly overengineered.

TODO: This is an initial commit and needs some docmentation.

<!-- pyscaffold-notes -->

## Note

This project has been set up using PyScaffold 4.2.1. For details and usage
information on PyScaffold see https://pyscaffold.org/.
